Task: ConvAI2_wild_evaluation
==============================
Description: Dataset collected during the wild evaluation of ConvaAI2 participants bots (http://convai.io). 60% train, 20% valid and 20% test is chosen at random from the whole dataset.

Tags: #ConvAI2_wild_evaluation, #All, #ChitChat

